/** \file SettingsUnit.cpp
	\brief Common (not related to plugins) settings window.
*/

/* Copyright (C) 2008-2009 Tomasz Ostrowski <tomasz.o.ostrowski at gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.

 * Miniscope is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <vcl.h>
#pragma hdrstop

#include "SettingsUnit.h"
#include "MiniscopeDeviceInterface.h"
#include <SysUtils.hpp>

//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma resource "*.dfm"
TfrmSettings *frmSettings;
//---------------------------------------------------------------------------
__fastcall TfrmSettings::TfrmSettings(TComponent* Owner)
	: TForm(Owner)
{
	this->appSettings = NULL;
}
//---------------------------------------------------------------------------
void __fastcall TfrmSettings::FormShow(TObject *Sender)
{
	lvScopePlugins->Items->Count = DeviceInterface::dlls.size();

	assert(appSettings);
	tmpSettings = *appSettings;
	chbAlwaysOnTop->Checked = tmpSettings.bAlwaysOnTop;
	cmbMaxUiLogLines->ItemIndex = -1;
	for (int i=0; i<cmbMaxUiLogLines->Items->Count; i++)
	{
		if ((unsigned int)StrToInt(cmbMaxUiLogLines->Items->Strings[i]) >= tmpSettings.iMaxUiLogLines)
		{
			cmbMaxUiLogLines->ItemIndex = i;
			break;
		}
	}
	if (cmbMaxUiLogLines->ItemIndex == -1)
	{
		cmbMaxUiLogLines->ItemHeight = cmbMaxUiLogLines->Items->Count - 1;
	}
	for (int i=0; i<cbGraphRefreshingFreq->Items->Count; i++)
	{
		if ((unsigned int)StrToInt(cbGraphRefreshingFreq->Items->Strings[i]) >= tmpSettings.iDisplayRefreshFreq)
		{
			cbGraphRefreshingFreq->ItemIndex = i;
			break;
		}
	}
	chbOscilloscopeGridX->Checked = tmpSettings.GraphOscilloscope.bGridX;
	chbOscilloscopeGridY->Checked = tmpSettings.GraphOscilloscope.bGridY;
	chbOscilloscopeGridLabels->Checked = tmpSettings.GraphOscilloscope.bGridLabels;
	chbSpectrumGridX->Checked = tmpSettings.GraphSpectrum.bGridX;
	chbSpectrumGridY->Checked = tmpSettings.GraphSpectrum.bGridY;
	chbSpectrumGridLabels->Checked = tmpSettings.GraphSpectrum.bGridLabels;
	chbRecorderGridX->Checked = tmpSettings.GraphRecorder.bGridX;
	chbRecorderGridY->Checked = tmpSettings.GraphRecorder.bGridY;
	chbRecorderGridLabels->Checked = tmpSettings.GraphRecorder.bGridLabels;
}
//---------------------------------------------------------------------------
void __fastcall TfrmSettings::btnCancelClick(TObject *Sender)
{
	this->Close();	
}
//---------------------------------------------------------------------------
void __fastcall TfrmSettings::btnApplyClick(TObject *Sender)
{
	tmpSettings.GraphOscilloscope.bGridX = chbOscilloscopeGridX->Checked;
	tmpSettings.GraphOscilloscope.bGridY = chbOscilloscopeGridY->Checked;
	tmpSettings.GraphOscilloscope.bGridLabels = chbOscilloscopeGridLabels->Checked;
	tmpSettings.GraphSpectrum.bGridX = chbSpectrumGridX->Checked;
	tmpSettings.GraphSpectrum.bGridY = chbSpectrumGridY->Checked;
	tmpSettings.GraphSpectrum.bGridLabels = chbSpectrumGridLabels->Checked;
	tmpSettings.GraphRecorder.bGridX = chbRecorderGridX->Checked;
	tmpSettings.GraphRecorder.bGridY = chbRecorderGridY->Checked;
	tmpSettings.GraphRecorder.bGridLabels = chbRecorderGridLabels->Checked;
	if (lvScopePlugins->Selected)
	{
		tmpSettings.asInputDeviceDllName = lvScopePlugins->Selected->Caption;
	}
	*appSettings = tmpSettings;
	this->Close();	
}
//---------------------------------------------------------------------------

void __fastcall TfrmSettings::chbAlwaysOnTopClick(TObject *Sender)
{
	tmpSettings.bAlwaysOnTop = chbAlwaysOnTop->Checked;	
}
//---------------------------------------------------------------------------

void __fastcall TfrmSettings::cmbMaxUiLogLinesChange(TObject *Sender)
{
	tmpSettings.iMaxUiLogLines = StrToInt(cmbMaxUiLogLines->Text);	
}
//---------------------------------------------------------------------------

void __fastcall TfrmSettings::lvScopePluginsData(TObject *Sender,
      TListItem *Item)
{
	int id = Item->Index;
	Item->Caption = ExtractFileName(DeviceInterface::dlls[id].name);
	if (Item->Caption == tmpSettings.asInputDeviceDllName)
		Item->ImageIndex = 0;
	else
		Item->ImageIndex = -1;
}
//---------------------------------------------------------------------------


void __fastcall TfrmSettings::cbGraphRefreshingFreqChange(TObject *Sender)
{
	tmpSettings.iDisplayRefreshFreq = StrToInt(cbGraphRefreshingFreq->Text);	
}
//---------------------------------------------------------------------------

